summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmcsgedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmcsgedit.h')
-rw-r--r--kpovmodeler/pmcsgedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmcsgedit.h b/kpovmodeler/pmcsgedit.h
index d7efc75d..1ec5d205 100644
--- a/kpovmodeler/pmcsgedit.h
+++ b/kpovmodeler/pmcsgedit.h
@@ -35,12 +35,13 @@ class TQComboBox;
class PMCSGEdit : public PMSolidObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMSolidObjectEdit Base;
public:
/**
* Creates a PMCSGEdit with parent and name
*/
- PMCSGEdit( TQWidget* parent, const char* name = 0 );
+ PMCSGEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -35,12 +35,13 @@ class TQComboBox;
public:
/**
- * Creates a PMCSGEdit with parent and name
+ * Creates a PMCSGEdit with tqparent and name
*/